@@ -3,7 +3,7 @@ from typing import Callable, Optional
 import logging
 # NDN Imports
 from ndn.app import NDNApp
-from ndn.encoding import Name, Component, make_data, MetaInfo, parse_data, InterestParam, BinaryStr, FormalName
+from ndn.encoding import Name, Component, make_data, MetaInfo
 from ndn.types import InterestNack, InterestTimeout, InterestCanceled, ValidationFailure
 # Custom Imports
 from .svs_base import SVSyncBase
